cal.Task (Task) — amici1

# `cal.Task` (Task)

Task(id, modified, created, start_date, start_time, user, owner_type, owner_id, summary, description, access_class, sequence, auto_type, priority, due_date, due_time, percent, state)

Master tables : cal.MyTasks (My tasks), cal.Tasks (Tasks)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Modified (modified) : The time when this database object was last modified.

- Created (created) : The time when this object was created.

- Start date (start_date) : See `<django.db.models.fields.DateField: start_date>`.

- Start time (start_time) : See `<lino.core.fields.TimeField: start_time>`.

- Author (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- Controlled by (type) (owner_type) : See `<django.db.models.fields.related.ForeignKey: owner_type>`.

- Controlled by (object) (owner_id) : See `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`.

- Short description (summary) : See `<django.db.models.fields.CharField: summary>`.

- Description (description) : See `<lino.core.fields.RichTextField: description>`.

- Access class (access_class) : Whether this is private, public or between.

- Revision (sequence) : See `<django.db.models.fields.IntegerField: sequence>`.

- No. (auto_type) : Contains the sequence number if this is an automatically generated component. Otherwise this field is empty.

- Priority (priority) : How urgent this task is.

- Due date (due_date) : See `<django.db.models.fields.DateField: due_date>`.

- Due time (due_time) : See `<lino.core.fields.TimeField: due_time>`.

- Duration value (percent) : See `<django.db.models.fields.IntegerField: percent>`.

- State (state) : The state of this Task. one of TaskStates.

- Name (name_column) : See `lino_xl.lib.cal.models.Task.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.cal.models.Task.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.cal.models.Task.overview`.

- Created (created_natural) : See `lino_xl.lib.cal.models.Task.created_natural`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
modified | Modified | The time when this database object was last modified.
created | Created | The time when this object was created.
start_date | Start date |
start_time | Start time |
user | Author | The author of this object. A pointer to lino.modlib.users.models.User.
owner_type | Controlled by (type) |
owner_id | Controlled by (object) |
summary | Short description |
description | Description |
access_class | Access class | Whether this is private, public or between.
sequence | Revision |
auto_type | No. | Contains the sequence number if this is an automatically generated component. Otherwise this field is empty.
priority | Priority | How urgent this task is.
due_date | Due date |
due_time | Due time |
percent | Duration value |
state | State | The state of this Task. one of TaskStates.
owner | Controlled by |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
created_natural | Created |